@@ -24,11 +24,11 @@ use Icinga\Module\Director\Web\Widget\ShowConfigFile;
 use Icinga\Web\Notification;
 use Exception;
 use RuntimeException;
-use dipl\Html\Html;
-use dipl\Html\HtmlString;
-use dipl\Html\Icon;
-use dipl\Html\Link;
-use dipl\Web\Url;
+use ipl\Html\Html;
+use ipl\Html\HtmlString;
+use gipfl\IcingaWeb2\Icon;
+use gipfl\IcingaWeb2\Link;
+use gipfl\IcingaWeb2\Url;
 
 class ConfigController extends ActionController
 {
@@ -142,8 +142,11 @@ class ConfigController extends ActionController
         $lastDeployedId = $this->db()->getLastDeploymentActivityLogId();
         $table = new ActivityLogTable($this->db());
         $table->setLastDeployedId($lastDeployedId);
+        if ($idRangeEx = $this->url()->getParam('idRangeEx')) {
+            $table->applyFilter(Filter::fromQueryString($idRangeEx));
+        }
         $filter = Filter::fromQueryString(
-            $this->url()->without(['page', 'limit', 'q'])->getQueryString()
+            $this->url()->without(['page', 'limit', 'q', 'idRangeEx'])->getQueryString()
         );
         $table->applyFilter($filter);
         if ($this->url()->hasParam('author')) {
@@ -445,7 +448,7 @@ class ConfigController extends ActionController
     }
 
     /**
-     * @return \dipl\Web\Widget\Tabs
+     * @return \gipfl\IcingaWeb2\Widget\Tabs
      */
     protected function configTabs()
     {
