@@ -2,10 +2,10 @@
 
 namespace Icinga\Module\Director\Controllers;
 
-use dipl\Html\Html;
-use dipl\Html\Link;
-use dipl\Web\Url;
-use dipl\Web\Widget\Tabs;
+use ipl\Html\Html;
+use gipfl\IcingaWeb2\Link;
+use gipfl\IcingaWeb2\Url;
+use gipfl\IcingaWeb2\Widget\Tabs;
 use Exception;
 use Icinga\Module\Director\CustomVariable\CustomVariableDictionary;
 use Icinga\Module\Director\Db\AppliedServiceSetLoader;
@@ -58,7 +58,7 @@ class HostController extends ObjectController
     {
         $host = $this->getHostObject();
         $this->addServicesHeader();
-        $this->addTitle($this->translate('Add Service: %s'), $host->getObjectName());
+        $this->addTitle($this->translate('Add Service to %s'), $host->getObjectName());
         $this->content()->add(
             IcingaAddServiceForm::load()
                 ->setHost($host)
@@ -71,7 +71,7 @@ class HostController extends ObjectController
     {
         $host = $this->getHostObject();
         $this->addServicesHeader();
-        $this->addTitle($this->translate('Add Service Set: %s'), $host->getObjectName());
+        $this->addTitle($this->translate('Add Service Set to %s'), $host->getObjectName());
         $this->content()->add(
             IcingaServiceSetForm::load()
                 ->setHost($host)
@@ -221,6 +221,7 @@ class HostController extends ObjectController
             $content->add($table);
         }
 
+        /* @deprecated to be removed in 1.8.0 #1850 #1851 */
         if ($applied = $host->vars()->get($db->settings()->magic_apply_for)) {
             if ($applied instanceof CustomVariableDictionary) {
                 $table = IcingaHostAppliedForServiceTable::load($host, $applied)
