@@ -2,7 +2,6 @@
 
 namespace Icinga\Module\Director\Controllers;
 
-use Icinga\Exception\NotFoundError;
 use Icinga\Module\Director\Forms\ImportRowModifierForm;
 use Icinga\Module\Director\Forms\ImportSourceForm;
 use Icinga\Module\Director\Web\ActionBar\AutomationObjectActionBar;
@@ -15,7 +14,7 @@ use Icinga\Module\Director\Web\Table\PropertymodifierTable;
 use Icinga\Module\Director\Web\Tabs\ImportsourceTabs;
 use Icinga\Module\Director\Web\Widget\ImportSourceDetails;
 use InvalidArgumentException;
-use dipl\Html\Link;
+use gipfl\IcingaWeb2\Link;
 
 class ImportsourceController extends ActionController
 {
@@ -44,6 +43,9 @@ class ImportsourceController extends ActionController
         }
     }
 
+    /**
+     * @throws \Icinga\Exception\NotFoundError
+     */
     protected function addMainActions()
     {
         $this->actions(new AutomationObjectActionBar(
@@ -66,7 +68,6 @@ class ImportsourceController extends ActionController
     }
 
     /**
-     * @throws \Icinga\Exception\IcingaException
      * @throws \Icinga\Exception\NotFoundError
      */
     public function indexAction()
@@ -95,7 +96,7 @@ class ImportsourceController extends ActionController
     }
 
     /**
-     * @throws NotFoundError
+     * @throws \Icinga\Exception\NotFoundError
      */
     public function editAction()
     {
@@ -124,7 +125,10 @@ class ImportsourceController extends ActionController
         $this->addTitle('Clone: %s', $source->get('source_name'));
         $form = new CloneImportSourceForm($source);
         $this->content()->add($form);
-        $form->handleRequest($this->getRequest());
+        $form->on(CloneImportSourceForm::ON_SUCCESS, function (CloneImportSourceForm $form) {
+            $this->getResponse()->redirectAndExit($form->getSuccessUrl());
+        });
+        $form->handleRequest($this->getServerRequest());
     }
 
     /**
@@ -239,7 +243,7 @@ class ImportsourceController extends ActionController
 
     /**
      * @return ImportSource
-     * @throws NotFoundError
+     * @throws \Icinga\Exception\NotFoundError
      */
     protected function getImportSource()
     {
