@@ -11,8 +11,8 @@ use Icinga\Module\Director\Web\Form\DirectorObjectForm;
 use Icinga\Module\Director\Objects\IcingaHost;
 use Icinga\Module\Director\Objects\IcingaService;
 use Icinga\Module\Director\Objects\IcingaServiceSet;
-use dipl\Html\Html;
-use dipl\Html\Link;
+use ipl\Html\Html;
+use gipfl\IcingaWeb2\Link;
 use RuntimeException;
 
 class IcingaServiceForm extends DirectorObjectForm
@@ -318,12 +318,14 @@ class IcingaServiceForm extends DirectorObjectForm
     protected function setupServiceElements()
     {
         if ($this->object) {
-            $this->addHidden('object_type', $this->object->object_type);
+            $objectType = $this->object->object_type;
         } elseif ($this->preferredObjectType) {
-            $this->addHidden('object_type', $this->preferredObjectType);
+            $objectType = $this->preferredObjectType;
         } else {
-            $this->addHidden('object_type', 'template');
+            $objectType = 'template';
         }
+        $this->addHidden('object_type', $objectType);
+        $forceCommandElements = $this->hasPermission('director/admin');
 
         $this->addNameElement()
              ->addHostObjectElement()
@@ -334,7 +336,7 @@ class IcingaServiceForm extends DirectorObjectForm
              ->addApplyForElement()
              ->groupMainProperties()
              ->addAssignmentElements()
-             ->addCheckCommandElements()
+             ->addCheckCommandElements($forceCommandElements)
              ->addCheckExecutionElements()
              ->addExtraInfoElements()
              ->addAgentAndZoneElements()
@@ -446,7 +448,10 @@ class IcingaServiceForm extends DirectorObjectForm
             'required' => true,
             'description' => $this->translate(
                 'This allows you to configure an assignment filter. Please feel'
-                . ' free to combine as many nested operators as you want'
+                . ' free to combine as many nested operators as you want. The'
+                . ' "contains" operator is valid for arrays only. Please use'
+                . ' wildcards and the = (equals) operator when searching for'
+                . ' partial string matches, like in *.example.com'
             )
         ]);
 
@@ -475,6 +480,7 @@ class IcingaServiceForm extends DirectorObjectForm
         $this->addNameElement()
              ->addChoices('service')
              ->addDisabledElement()
+             ->addGroupsElement()
              ->groupMainProperties()
              ->addCheckCommandElements()
              ->addExtraInfoElements()
@@ -521,6 +527,7 @@ class IcingaServiceForm extends DirectorObjectForm
 
         $this->addNameElement()
              ->addDisabledElement()
+             ->addGroupsElement()
              ->groupMainProperties();
 
         if ($this->hasPermission('director/admin')) {
