@@ -5,11 +5,13 @@ namespace Icinga\Module\Director\Core;
 use Exception;
 use Icinga\Exception\NotFoundError;
 use Icinga\Module\Director\Db;
+use Icinga\Module\Director\Hook\DeploymentHook;
 use Icinga\Module\Director\IcingaConfig\IcingaConfig;
 use Icinga\Module\Director\Objects\IcingaObject;
 use Icinga\Module\Director\Objects\IcingaCommand;
 use Icinga\Module\Director\Objects\DirectorDeploymentLog;
 use Icinga\Module\Director\Objects\IcingaZone;
+use Icinga\Web\Hook;
 use RuntimeException;
 
 class CoreApi implements DeploymentApiInterface
@@ -75,7 +77,7 @@ class CoreApi implements DeploymentApiInterface
             return null;
         }
 
-        if (preg_match('/^v?(\d\.\d+\.\d+)/', $version, $match)) {
+        if (preg_match('/^[rv]?(\d\.\d+\.\d+)/', $version, $match)) {
             return $match[1];
         } else {
             return null;
@@ -315,7 +317,7 @@ class CoreApi implements DeploymentApiInterface
             "f = function() {\n"
             . '  existing = get_%s("%s")'
             . "\n  if (existing) { return false }"
-            . "\n%s\n}\n__run_with_activation_context(f)\n",
+            . "\n%s\n}\nInternal.run_with_activation_context(f)\n",
             $key,
             $object->get('object_name'),
             (string) $object
@@ -685,7 +687,7 @@ constants
         $running = DirectorDeploymentLog::getRelatedToActiveStage($this, $db);
         if ($running !== null) {
             foreach ($empty as $deployment) {
-                if ($deployment->get('start_time') < $running->get('start_time')) {
+                if ($deployment->getDeploymentTimestamp() < $running->getDeploymentTimestamp()) {
                     $deployment->set('stage_collected', 'n');
                     $deployment->store();
                     $this->deleteStage($this->getPackageName(), $deployment->get('stage_name'));
@@ -816,6 +818,12 @@ constants
             // 'module_name'    => $moduleName,
         ));
 
+        /** @var DeploymentHook[] $hooks */
+        $hooks = Hook::all('director/Deployment');
+        foreach ($hooks as $hook) {
+            $hook->beforeDeploy($deployment);
+        }
+
         $this->assertPackageExists($packageName);
 
         $response = $this->client()->post('config/stages/' . urlencode($packageName), [
@@ -826,20 +834,23 @@ constants
         // $deployment->duration_ms = $duration;
         $deployment->set('duration_dump', $duration);
 
+        $succeeded = 'n';
         if ($response->succeeded()) {
             if ($stage = $response->getResult('stage', ['package' => $packageName])) { // Status?
                 $deployment->set('stage_name', key($stage));
-                $deployment->set('dump_succeeded', 'y');
-            } else {
-                $deployment->set('dump_succeeded', 'n');
+                $succeeded = 'y';
             }
-        } else {
-            $deployment->set('dump_succeeded', 'n');
         }
-
+        $deployment->set('dump_succeeded', $succeeded);
         $deployment->store($db);
 
-        return $deployment->set('dump_succeeded', 'y');
+        if ($succeeded === 'y') {
+            foreach ($hooks as $hook) {
+                $hook->onSuccessfullDump($deployment);
+            }
+        }
+
+        return $deployment;
     }
 
     protected function shortenStartupLog($log)
