@@ -2,6 +2,8 @@
 
 namespace Icinga\Module\Director\Dashboard\Dashlet;
 
+use Icinga\Module\Director\Acl;
+
 class ServiceObjectDashlet extends Dashlet
 {
     protected $icon = 'services';
@@ -15,11 +17,18 @@ class ServiceObjectDashlet extends Dashlet
 
     public function getUrl()
     {
-        return 'director/services';
+        return 'director/dashboard?name=services';
     }
 
     public function listRequiredPermissions()
     {
-        return array('director/admin');
+        return ['director/services'];
+    }
+
+    public function isAllowed()
+    {
+        $acl = Acl::instance();
+        return $acl->hasPermission('director/services')
+            || $acl->hasPermission('director/service_sets');
     }
 }
