@@ -21,7 +21,7 @@ class ExtensibleSet
 
     protected $inheritedValues = array();
 
-    protected $fromDb = false;
+    protected $fromDb;
 
     /**
      * @var IcingaObject
@@ -440,6 +440,10 @@ class ExtensibleSet
             );
         }
 
+        if (empty($this->allowedValues)) {
+            return array();
+        }
+
         return array_combine($this->allowedValues, $this->allowedValues);
     }
 
