@@ -19,6 +19,7 @@ use Icinga\Module\Director\Objects\SyncProperty;
 use Icinga\Module\Director\Objects\SyncRule;
 use Icinga\Module\Director\Objects\SyncRun;
 use Icinga\Exception\IcingaException;
+use Icinga\Module\Director\Repository\IcingaTemplateRepository;
 use InvalidArgumentException;
 
 class Sync
@@ -98,7 +99,8 @@ class Sync
      * Retrieve modifications a given SyncRule would apply
      *
      * @return array  Array of IcingaObject elements
-     * @throws Exception
+     * @throws \Icinga\Exception\NotFoundError
+     * @throws \Icinga\Module\Director\Exception\DuplicateKeyException
      */
     public function getExpectedModifications()
     {
@@ -202,7 +204,6 @@ class Sync
      * Instantiates all related ImportSource objects
      *
      * @return self
-     * @throws IcingaException
      * @throws \Icinga\Exception\NotFoundError
      */
     protected function prepareRelatedImportSources()
@@ -249,7 +250,7 @@ class Sync
     /**
      * Fetch latest imported data rows from all involved import sources
      * @return Sync
-     * @throws IcingaException
+     * @throws \Icinga\Exception\NotFoundError
      */
     protected function fetchImportedData()
     {
@@ -433,9 +434,8 @@ class Sync
 
     /**
      * @return array
-     * @throws IcingaException
      * @throws \Icinga\Exception\NotFoundError
-     * @throws \Icinga\Exception\ProgrammingError
+     * @throws \Icinga\Module\Director\Exception\DuplicateKeyException
      */
     protected function prepareNewObjects()
     {
@@ -446,6 +446,8 @@ class Sync
             $sourceId = $source->id;
 
             foreach ($this->imported[$sourceId] as $key => $row) {
+                // Workaround: $a["10"] = "val"; -> array_keys($a) = [(int) 10]
+                $key = (string) $key;
                 if (! array_key_exists($key, $objects)) {
                     // Safe default values for object_type and object_name
                     if ($ruleObjectType === 'datalistEntry') {
@@ -476,9 +478,8 @@ class Sync
      * @param $row
      * @param DbObject $object
      * @param $sourceId
-     * @throws IcingaException
      * @throws \Icinga\Exception\NotFoundError
-     * @throws \Icinga\Exception\ProgrammingError
+     * @throws \Icinga\Module\Director\Exception\DuplicateKeyException
      */
     protected function prepareNewObject($row, DbObject $object, $sourceId)
     {
@@ -598,7 +599,8 @@ class Sync
      * TODO: Split this into smaller methods
      *
      * @return DbObject|IcingaObject[] List of modified IcingaObjects
-     * @throws Exception
+     * @throws \Icinga\Exception\NotFoundError
+     * @throws \Icinga\Module\Director\Exception\DuplicateKeyException
      */
     protected function prepare()
     {
@@ -663,7 +665,7 @@ class Sync
     /**
      * @param $key
      * @param DbObject|IcingaObject $object
-     * @throws IcingaException
+     * @throws \Icinga\Exception\NotFoundError
      */
     protected function processObject($key, $object)
     {
@@ -677,7 +679,7 @@ class Sync
     /**
      * @param $key
      * @param DbObject|IcingaObject $object
-     * @throws IcingaException
+     * @throws \Icinga\Exception\NotFoundError
      */
     protected function refreshObject($key, $object)
     {
@@ -812,6 +814,8 @@ class Sync
     protected function prepareCache()
     {
         PrefetchCache::initialize($this->db);
+        IcingaTemplateRepository::clear();
+
         $ruleObjectType = $this->rule->get('object_type');
 
         $dummy = IcingaObject::createByType($ruleObjectType);
