@@ -21,6 +21,7 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         'disabled'               => 'n',
         'apply_to'               => null,
         'parent_host_id'         => null,
+        'parent_host_var'        => null,
         'parent_service_id'      => null,
         'child_host_id'          => null,
         'child_service_id'       => null,
@@ -39,6 +40,12 @@ class IcingaDependency extends IcingaObject implements ExportInterface
 
     protected $supportsApplyRules = true;
 
+    /**
+     * @internal
+     * @var bool
+     */
+    protected $renderForArray = false;
+
     protected $relatedSets = [
         'states' => 'StateFilterSet',
     ];
@@ -58,6 +65,13 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         'ignore_soft_states'    => 'ignore_soft_states'
     ];
 
+    protected $propertiesNotForRendering = [
+        'id',
+        'object_name',
+        'object_type',
+        'apply_to',
+    ];
+
     public function getUniqueIdentifier()
     {
         return $this->getObjectName();
@@ -105,20 +119,15 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         return $object;
     }
 
-    /**
-     * Do not render internal property apply_to
-     *
-     * Avoid complaints for method names with underscore:
-     * @codingStandardsIgnoreStart
-     *
-     * @return string
-     */
-    public function renderApply_to()
+    public function parentHostIsVar()
     {
-        // @codingStandardsIgnoreEnd
-        return '';
+        return $this->get('parent_host_var') !== null;
     }
 
+    /**
+     * @return string
+     * @throws ConfigurationError
+     */
     protected function renderObjectHeader()
     {
         if ($this->isApplyRule()) {
@@ -129,18 +138,97 @@ class IcingaDependency extends IcingaObject implements ExportInterface
                 );
             }
 
-            return sprintf(
-                "%s %s %s to %s {\n",
-                $this->getObjectTypeName(),
-                $this->getType(),
-                c::renderString($this->getObjectName()),
-                ucfirst($to)
-            );
+            if ($this->renderForArray) {
+                return $this->renderArrayObjectHeader($to);
+            } else {
+                return $this->renderSingleObjectHeader($to);
+            }
         } else {
             return parent::renderObjectHeader();
         }
     }
 
+    protected function renderSingleObjectHeader($to)
+    {
+        return sprintf(
+            "%s %s %s to %s {\n",
+            $this->getObjectTypeName(),
+            $this->getType(),
+            c::renderString($this->getObjectName()),
+            ucfirst($to)
+        );
+    }
+
+    protected function renderArrayObjectHeader($to)
+    {
+        return sprintf(
+            "%s %s %s for (host_parent_name in %s) to %s {\n",
+            $this->getObjectTypeName(),
+            $this->getType(),
+            c::renderString($this->getObjectName()),
+            $this->get('parent_host_var'),
+            ucfirst($to)
+        );
+    }
+
+    /**
+     * @return string
+     */
+    protected function renderSuffix()
+    {
+        if (! $this->parentHostIsVar()) {
+            return parent::renderSuffix();
+        }
+
+        if (\strlen($this->get('assign_filter')) > 0) {
+            $suffix = parent::renderSuffix();
+        } else {
+            $suffix = '    assign where ' . $this->renderAssignFilterExtension('')
+                . "\n" . parent::renderSuffix();
+        }
+
+
+        if ($this->renderForArray) {
+            return $suffix;
+        } else {
+            return $suffix . $this->renderCloneForArray();
+        }
+    }
+
+    protected function renderCloneForArray()
+    {
+        $clone = clone($this);
+        $clone->renderForArray = true;
+
+        return $clone->toConfigString();
+    }
+
+    /**
+     * @codingStandardsIgnoreStart
+     */
+    public function renderAssign_Filter()
+    {
+        if ($this->parentHostIsVar()) {
+            return preg_replace(
+                '/\n$/m',
+                $this->renderAssignFilterExtension(),
+                parent::renderAssign_Filter() . "\n"
+            );
+        } else {
+            return parent::renderAssign_Filter();
+        }
+    }
+
+    protected function renderAssignFilterExtension($pre = ' && ')
+    {
+        $varName = $this->get('parent_host_var');
+        if ($this->renderForArray) {
+            return sprintf('%stypeof(%s) == Array', $pre, $varName);
+        } else {
+            return sprintf('%stypeof(%s) == String', $pre, $varName);
+        }
+    }
+
     protected function setKey($key)
     {
         // TODO: Check if this method can be removed
@@ -304,7 +392,6 @@ class IcingaDependency extends IcingaObject implements ExportInterface
     public function renderParent_host_id()
     {
         // @codingStandardsIgnoreEnd
-
         return $this->renderRelationProperty(
             'parent_host',
             $this->get('parent_host_id'),
@@ -312,6 +399,29 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         );
     }
 
+    /**
+     * Render parent_host_var as parent_host
+     * @codingStandardsIgnoreStart
+     *
+     * @return string
+     */
+    public function renderParent_host_var()
+    {
+        // @codingStandardsIgnoreEnd
+        if ($this->renderForArray) {
+            return c::renderKeyValue(
+                'parent_host_name',
+                'host_parent_name'
+            );
+        }
+
+        // @codingStandardsIgnoreEnd
+        return c::renderKeyValue(
+            'parent_host_name',
+            $this->get('parent_host_var')
+        );
+    }
+
     /**
      * Render child_service_id as host_name
      *
@@ -354,9 +464,19 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         );
     }
 
-    //special case for parent service set as plain string for Apply rules
+    //
+    /**
+     * Render parent_service_by_name as parent_service_name
+     *
+     * Special case for parent service set as plain string for Apply rules
+     *
+     * @codingStandardsIgnoreStart
+     *
+     * @return string
+     */
     public function renderParent_service_by_name()
     {
+        // @codingStandardsIgnoreEnd
         return c::renderKeyValue(
             'parent_service_name',
             c::renderString($this->get('parent_service_by_name'))
@@ -383,8 +503,8 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         $objKey = $this->unresolvedRelatedProperties[$name];
 
         # related services need array key
-        if ($class == "Icinga\Module\Director\Objects\IcingaService" ) {
-            if ($name === 'parent_service_id' && $this->object_type === 'apply' ) {
+        if ($class === IcingaService::class) {
+            if ($name === 'parent_service_id' && $this->get('object_type') === 'apply') {
                 //special case , parent service can be set as simple string for Apply
                 if ($this->properties['parent_host_id'] === null) {
                     $this->reallySet(
@@ -412,7 +532,7 @@ class IcingaDependency extends IcingaObject implements ExportInterface
             }
 
             try {
-                $class::load( $objKey, $this->connection);
+                $class::load($objKey, $this->connection);
             } catch (NotFoundError $e) {
                 // Not a simple service on host
                 // Hunt through inherited services, use service assigned to
@@ -430,7 +550,7 @@ class IcingaDependency extends IcingaObject implements ExportInterface
                         'object_name' => $this->unresolvedRelatedProperties[$name]
                     ];
                     try {
-                        $object = $class::load( $objKey, $this->connection);
+                        $object = $class::load($objKey, $this->connection);
                     } catch (NotFoundError $e) {
                         continue;
                     }
@@ -492,27 +612,15 @@ class IcingaDependency extends IcingaObject implements ExportInterface
 
     protected function getRelatedProperty($key)
     {
-        $idKey = $key . '_id';
-        if ($this->hasUnresolvedRelatedProperty($idKey)) {
-            return $this->unresolvedRelatedProperties[$idKey];
+        $related = parent::getRelatedProperty($key);
+        // handle special case for plain string parent service on Dependency
+        // Apply rules
+        if ($related === null && $key === 'parent_service'
+            && null !== $this->get('parent_service_by_name')
+        ) {
+            return $this->get('parent_service_by_name');
         }
 
-        if ($id = $this->get($idKey)) {
-            /** @var IcingaObject $class */
-            $class = $this->getRelationClass($key);
-            $object = $class::loadWithAutoIncId($id, $this->connection);
-
-            return $object->getObjectName();
-        } else {
-            // handle special case for plain string parent service on Dependency
-            // Apply rules
-            if ($key === 'parent_service'
-                && null !== $this->get('parent_service_by_name')
-            ) {
-                return $this->get('parent_service_by_name');
-            }
-        }
-
-        return null;
+        return $related;
     }
 }
