@@ -309,7 +309,7 @@ abstract class IcingaObject extends DbObject implements IcingaConfigRenderer
      * @param $id
      * @return string
      */
-    protected function getRelatedObjectName($property, $id)
+    public function getRelatedObjectName($property, $id)
     {
         return $this->getRelatedObject($property, $id)->getObjectName();
     }
@@ -2359,12 +2359,7 @@ abstract class IcingaObject extends DbObject implements IcingaConfigRenderer
             );
         }
 
-        $str = sprintf(
-            "define %s {\n$name",
-            $type,
-            $name
-        );
-
+        $str = "define $type {\n$name";
         if ($this->isTemplate()) {
             $str .= c1::renderKeyValue('register', '0');
         }
@@ -2558,6 +2553,8 @@ abstract class IcingaObject extends DbObject implements IcingaConfigRenderer
             $type = 'templateChoiceHost';
         } elseif ($type === 'service_template_choice') {
             $type = 'TemplateChoiceService';
+        } elseif ($type === 'scheduled_downtime') {
+            $type = 'ScheduledDowntime';
         }
 
         return 'Icinga\\Module\\Director\\Objects\\' . $prefix . ucfirst($type);
@@ -3013,7 +3010,7 @@ abstract class IcingaObject extends DbObject implements IcingaConfigRenderer
     {
         $params = array();
 
-        if ($this->isApplyRule()) {
+        if ($this->isApplyRule() && ! $this instanceof IcingaScheduledDowntime) {
             $params['id'] = $this->get('id');
         } else {
             $params = array('name' => $this->getObjectName());
