@@ -3,24 +3,28 @@
 namespace Icinga\Module\Director\Objects;
 
 use Icinga\Application\Benchmark;
-use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\NotFoundError;
+use Icinga\Module\Director\Application\MemoryLimit;
 use Icinga\Module\Director\Data\Db\DbObjectWithSettings;
 use Icinga\Module\Director\Db;
+use Icinga\Module\Director\DirectorObject\Automation\ExportInterface;
 use Icinga\Module\Director\Exception\DuplicateKeyException;
 use Icinga\Module\Director\Hook\PropertyModifierHook;
 use Icinga\Module\Director\Import\Import;
 use Icinga\Module\Director\Import\SyncUtils;
+use InvalidArgumentException;
 use Exception;
 
-class ImportSource extends DbObjectWithSettings
+class ImportSource extends DbObjectWithSettings implements ExportInterface
 {
     protected $table = 'import_source';
 
-    protected $keyName = 'id';
+    protected $keyName = 'source_name';
 
     protected $autoincKeyName = 'id';
 
+    protected $protectAutoinc = false;
+
     protected $defaultProperties = [
         'id'                 => null,
         'source_name'        => null,
@@ -44,6 +48,8 @@ class ImportSource extends DbObjectWithSettings
 
     private $rowModifiers;
 
+    private $loadedRowModifiers;
+
     private $newRowModifiers;
 
     /**
@@ -51,29 +57,44 @@ class ImportSource extends DbObjectWithSettings
      */
     public function export()
     {
-        $plain = (object) $this->getProperties();
-        $plain->originalId = $plain->id;
-        unset($plain->id);
+        $plain = $this->getProperties();
+        $plain['originalId'] = $plain['id'];
+        unset($plain['id']);
 
         foreach ($this->stateProperties as $key) {
-            unset($plain->$key);
+            unset($plain[$key]);
         }
 
-        $plain->settings = (object) $this->getSettings();
-        $plain->modifiers = $this->exportRowModifiers();
+        $plain['settings'] = (object) $this->getSettings();
+        $plain['modifiers'] = $this->exportRowModifiers();
+        ksort($plain);
 
-        return $plain;
+        return (object) $plain;
     }
 
+    /**
+     * @param $plain
+     * @param Db $db
+     * @param bool $replace
+     * @return ImportSource
+     * @throws DuplicateKeyException
+     * @throws NotFoundError
+     */
     public static function import($plain, Db $db, $replace = false)
     {
         $properties = (array) $plain;
-        $id = $properties['originalId'];
-        unset($properties['originalId']);
+        if (isset($properties['originalId'])) {
+            $id = $properties['originalId'];
+            unset($properties['originalId']);
+        } else {
+            $id = null;
+        }
         $name = $properties['source_name'];
 
         if ($replace && static::existsWithNameAndId($name, $id, $db)) {
             $object = static::loadWithAutoIncId($id, $db);
+        } elseif ($replace && static::exists($name, $db)) {
+            $object = static::load($name, $db);
         } elseif (static::existsWithName($name, $db)) {
             throw new DuplicateKeyException(
                 'Import Source %s already exists',
@@ -83,19 +104,68 @@ class ImportSource extends DbObjectWithSettings
             $object = static::create([], $db);
         }
 
-        $object->newRowModifiers = $properties['modifiers'];
-        unset($properties['modifiers']);
         $object->setProperties($properties);
+        if ($id !== null) {
+            // TODO: really?
+            $object->reallySet('id', $id);
+        }
 
         return $object;
     }
 
+    public function setModifiers(array $modifiers)
+    {
+        if ($this->loadedRowModifiers === null && $this->hasBeenLoadedFromDb()) {
+            $this->loadedRowModifiers = $this->fetchRowModifiers();
+        }
+        $current = $this->loadedRowModifiers;
+        if ($current !== null && count($current) !== count($modifiers)) {
+            $this->newRowModifiers = $modifiers;
+        } else {
+            $i = 0;
+            $modified = false;
+            foreach ($modifiers as $props) {
+                $this->loadedRowModifiers[$i]->setProperties((array) $props);
+                if ($this->loadedRowModifiers[$i]->hasBeenModified()) {
+                    $modified = true;
+                }
+            }
+            if ($modified) {
+                // TOOD: no newRowModifiers, directly store loaded ones if diff
+                $this->newRowModifiers = $modifiers;
+            }
+        }
+    }
+
+    public function hasBeenModified()
+    {
+        return $this->newRowModifiers !== null
+            || parent::hasBeenModified();
+    }
+
+    public function getUniqueIdentifier()
+    {
+        return $this->get('source_name');
+    }
+
+    /**
+     * @param $name
+     * @param Db $connection
+     * @return ImportSource
+     * @throws NotFoundError
+     */
     public static function loadByName($name, Db $connection)
     {
         $db = $connection->getDbAdapter();
         $properties = $db->fetchRow(
             $db->select()->from('import_source')->where('source_name = ?', $name)
         );
+        if ($properties === false) {
+            throw new NotFoundError(sprintf(
+                'There is no such Import Source: "%s"',
+                $name
+            ));
+        }
 
         return static::create([], $connection)->setDbProperties($properties);
     }
@@ -111,15 +181,25 @@ class ImportSource extends DbObjectWithSettings
         );
     }
 
+    /**
+     * @param string $name
+     * @param int $id
+     * @param Db $connection
+     * @api internal
+     * @return bool
+     */
     protected static function existsWithNameAndId($name, $id, Db $connection)
     {
         $db = $connection->getDbAdapter();
+        $dummy = new static;
+        $idCol = $dummy->autoincKeyName;
+        $keyCol = $dummy->keyName;
 
         return (string) $id === (string) $db->fetchOne(
             $db->select()
-                ->from('import_source', 'id')
-                ->where('id = ?', $id)
-                ->where('source_name = ?', $name)
+                ->from($dummy->table, $idCol)
+                ->where("$idCol = ?", $id)
+                ->where("$keyCol = ?", $name)
         );
     }
 
@@ -136,6 +216,7 @@ class ImportSource extends DbObjectWithSettings
     /**
      * @param bool $required
      * @return ImportRun|null
+     * @throws NotFoundError
      */
     public function fetchLastRun($required = false)
     {
@@ -171,6 +252,7 @@ class ImportSource extends DbObjectWithSettings
      * @param $timestamp
      * @param bool $required
      * @return ImportRun|null
+     * @throws NotFoundError
      */
     public function fetchLastRunBefore($timestamp, $required = false)
     {
@@ -186,7 +268,7 @@ class ImportSource extends DbObjectWithSettings
         $query = $db->select()->from(
             ['ir' => 'import_run'],
             'ir.id'
-        )->where('ir.source_id = ?', $this->id)
+        )->where('ir.source_id = ?', $this->get('id'))
         ->where('ir.start_time < ?', date('Y-m-d H:i:s', $timestamp))
         ->order('ir.start_time DESC')
         ->limit(1);
@@ -200,12 +282,17 @@ class ImportSource extends DbObjectWithSettings
         }
     }
 
+    /**
+     * @param $required
+     * @return null
+     * @throws NotFoundError
+     */
     protected function nullUnlessRequired($required)
     {
         if ($required) {
             throw new NotFoundError(
                 'No data has been imported for "%s" yet',
-                $this->source_name
+                $this->get('source_name')
             );
         }
 
@@ -253,6 +340,9 @@ class ImportSource extends DbObjectWithSettings
 
     protected function applyPropertyModifierToRow(PropertyModifierHook $modifier, $key, $row)
     {
+        if (! is_object($row)) {
+            throw new InvalidArgumentException('Every imported row MUST be an object');
+        }
         if ($modifier->requiresRow()) {
             $modifier->setRow($row);
         }
@@ -267,10 +357,10 @@ class ImportSource extends DbObjectWithSettings
 
         $target = $modifier->getTargetProperty($key);
         if (strpos($target, '.') !== false) {
-            throw new ConfigurationError(
+            throw new InvalidArgumentException(sprintf(
                 'Cannot set value for nested key "%s"',
                 $target
-            );
+            ));
         }
 
         if (is_array($value) && ! $modifier->hasArraySupport()) {
@@ -304,23 +394,26 @@ class ImportSource extends DbObjectWithSettings
     public function fetchRowModifiers()
     {
         $db = $this->getDb();
-
         $modifiers = ImportRowModifier::loadAll(
             $this->getConnection(),
             $db->select()
                ->from('import_row_modifier')
-               ->where('source_id = ?', $this->id)
+               ->where('source_id = ?', $this->get('id'))
                ->order('priority ASC')
         );
 
-        return $modifiers;
+        if ($modifiers) {
+            return $modifiers;
+        } else {
+            return [];
+        }
     }
 
     protected function fetchFlatRowModifiers()
     {
         $mods = [];
         foreach ($this->fetchRowModifiers() as $mod) {
-            $mods[] = [$mod->property_name, $mod->getInstance()];
+            $mods[] = [$mod->get('property_name'), $mod->getInstance()];
         }
 
         return $mods;
@@ -331,11 +424,12 @@ class ImportSource extends DbObjectWithSettings
         $modifiers = [];
 
         foreach ($this->fetchRowModifiers() as $mod) {
-            if (! array_key_exists($mod->property_name, $modifiers)) {
-                $modifiers[$mod->property_name] = [];
+            $name = $mod->get('property_name');
+            if (! array_key_exists($name, $modifiers)) {
+                $modifiers[$name] = [];
             }
 
-            $modifiers[$mod->property_name][] = $mod->getInstance();
+            $modifiers[$name][] = $mod->getInstance();
         }
 
         $this->rowModifiers = $modifiers;
@@ -356,32 +450,39 @@ class ImportSource extends DbObjectWithSettings
         return array_keys($list);
     }
 
+    /**
+     * @param bool $runImport
+     * @return bool
+     * @throws DuplicateKeyException
+     */
     public function checkForChanges($runImport = false)
     {
         $hadChanges = false;
 
-        Benchmark::measure('Starting with import ' . $this->source_name);
+        $name = $this->get('source_name');
+        Benchmark::measure("Starting with import $name");
+        $this->raiseLimits();
         try {
             $import = new Import($this);
-            $this->last_attempt = date('Y-m-d H:i:s');
+            $this->set('last_attempt', date('Y-m-d H:i:s'));
             if ($import->providesChanges()) {
-                Benchmark::measure('Found changes for ' . $this->source_name);
+                Benchmark::measure("Found changes for $name");
                 $hadChanges = true;
-                $this->import_state = 'pending-changes';
+                $this->set('import_state', 'pending-changes');
 
                 if ($runImport && $import->run()) {
-                    Benchmark::measure('Import succeeded for ' . $this->source_name);
-                    $this->import_state = 'in-sync';
+                    Benchmark::measure("Import succeeded for $name");
+                    $this->set('import_state', 'in-sync');
                 }
             } else {
-                $this->import_state = 'in-sync';
+                $this->set('import_state', 'in-sync');
             }
 
-            $this->last_error_message = null;
+            $this->set('last_error_message', null);
         } catch (Exception $e) {
-            $this->import_state = 'failing';
-            Benchmark::measure('Import failed for ' . $this->source_name);
-            $this->last_error_message = $e->getMessage();
+            $this->set('import_state', 'failing');
+            Benchmark::measure("Import failed for $name");
+            $this->set('last_error_message', $e->getMessage());
         }
 
         if ($this->hasBeenModified()) {
@@ -391,8 +492,25 @@ class ImportSource extends DbObjectWithSettings
         return $hadChanges;
     }
 
+    /**
+     * @return bool
+     * @throws DuplicateKeyException
+     */
     public function runImport()
     {
         return $this->checkForChanges(true);
     }
+
+    /**
+     * Raise PHP resource limits
+     *
+     * @return $this;
+     */
+    protected function raiseLimits()
+    {
+        MemoryLimit::raiseTo('1024M');
+        ini_set('max_execution_time', 0);
+
+        return $this;
+    }
 }
