@@ -12,7 +12,8 @@ class Settings
 
     protected $defaults = [
         'default_global_zone'             => 'director-global',
-        'magic_apply_for'                 => '_director_apply_for',
+        'icinga_package_name'             => 'director',
+        'magic_apply_for'                 => '_director_apply_for', /* @deprecated to be removed in 1.8.0 #1850 #1851 */
         'config_format'                   => 'v2',
         'override_services_varname'       => '_override_servicevars',
         'override_services_templatename'  => 'host var overrides (Director)',
@@ -24,6 +25,7 @@ class Settings
         'self-service/agent_name'         => 'fqdn',
         'self-service/transform_hostname' => '0',
         'self-service/global_zones'       => ['director-global'],
+        'ignore_bug7530'                  => 'n',
         // 'experimental_features'       => null, // 'allow'
         // 'master_zone'                 => null,
     ];
@@ -55,6 +57,11 @@ class Settings
         return $this->db;
     }
 
+    /**
+     * @param $key
+     * @param null $default
+     * @return mixed|null
+     */
     public function get($key, $default = null)
     {
         if (null === ($value = $this->getStoredValue($key, $default))) {
@@ -64,6 +71,11 @@ class Settings
         }
     }
 
+    /**
+     * @param $key
+     * @param null $default
+     * @return mixed|null
+     */
     public function getStoredValue($key, $default = null)
     {
         if (null === ($value = $this->getSetting($key))) {
@@ -95,6 +107,12 @@ class Settings
         }
     }
 
+    /**
+     * @param $name
+     * @param $value
+     * @return $this
+     * @throws \Zend_Db_Adapter_Exception
+     */
     public function set($name, $value)
     {
         $db = $this->db;
@@ -172,11 +190,20 @@ class Settings
         $this->cache = (array) $db->fetchPairs($query);
     }
 
+    /**
+     * @param $key
+     * @return mixed|null
+     */
     public function __get($key)
     {
         return $this->get($key);
     }
 
+    /**
+     * @param $key
+     * @param $value
+     * @throws \Zend_Db_Adapter_Exception
+     */
     public function __set($key, $value)
     {
         $this->set($key, $value);
