@@ -13,12 +13,14 @@ use Icinga\Security\SecurityException;
 use Icinga\Web\Controller;
 use Icinga\Web\UrlParams;
 use InvalidArgumentException;
-use dipl\Compat\Translator;
-use dipl\Html\Link;
-use dipl\Translation\TranslationHelper;
-use dipl\Web\Widget\ControlsAndContent;
-use dipl\Web\Controller\Extension\ControlsAndContentHelper;
-use dipl\Zf1\SimpleViewRenderer;
+use gipfl\IcingaWeb2\Translator;
+use gipfl\IcingaWeb2\Link;
+use gipfl\Translation\TranslationHelper;
+use gipfl\IcingaWeb2\Widget\ControlsAndContent;
+use gipfl\IcingaWeb2\Controller\Extension\ControlsAndContentHelper;
+use gipfl\IcingaWeb2\Zf1\SimpleViewRenderer;
+use GuzzleHttp\Psr7\ServerRequest;
+use Psr\Http\Message\ServerRequestInterface;
 
 abstract class ActionController extends Controller implements ControlsAndContent
 {
@@ -118,6 +120,14 @@ abstract class ActionController extends Controller implements ControlsAndContent
         return $this;
     }
 
+    /**
+     * @return ServerRequestInterface
+     */
+    protected function getServerRequest()
+    {
+        return ServerRequest::fromGlobals();
+    }
+
     protected function applyPaginationLimits(Paginatable $paginatable, $limit = 25, $offset = null)
     {
         $limit = $this->params->get('limit', $limit);
@@ -183,7 +193,8 @@ abstract class ActionController extends Controller implements ControlsAndContent
             $viewRenderer = null;
         }
 
-        if ($this->getRequest()->isApiRequest()) {
+        $cType = $this->getResponse()->getHeader('Content-Type', true);
+        if ($this->getRequest()->isApiRequest() || ($cType !== null && $cType !== 'text/html')) {
             $this->_helper->layout()->disableLayout();
             if ($viewRenderer) {
                 $viewRenderer->disable();
