@@ -2,7 +2,7 @@
 
 namespace Icinga\Module\Director\Web\Controller;
 
-use dipl\Html\Html;
+use ipl\Html\Html;
 use Icinga\Exception\IcingaException;
 use Icinga\Exception\InvalidPropertyException;
 use Icinga\Exception\NotFoundError;
@@ -12,8 +12,10 @@ use Icinga\Module\Director\Exception\NestingError;
 use Icinga\Module\Director\Forms\DeploymentLinkForm;
 use Icinga\Module\Director\Forms\IcingaCloneObjectForm;
 use Icinga\Module\Director\Forms\IcingaObjectFieldForm;
+use Icinga\Module\Director\Objects\IcingaCommand;
 use Icinga\Module\Director\Objects\IcingaObject;
 use Icinga\Module\Director\Objects\IcingaObjectGroup;
+use Icinga\Module\Director\Objects\IcingaService;
 use Icinga\Module\Director\Objects\IcingaServiceSet;
 use Icinga\Module\Director\RestApi\IcingaObjectHandler;
 use Icinga\Module\Director\Web\Controller\Extension\ObjectRestrictions;
@@ -23,7 +25,7 @@ use Icinga\Module\Director\Web\Table\ActivityLogTable;
 use Icinga\Module\Director\Web\Table\GroupMemberTable;
 use Icinga\Module\Director\Web\Table\IcingaObjectDatafieldTable;
 use Icinga\Module\Director\Web\Tabs\ObjectTabs;
-use dipl\Html\Link;
+use gipfl\IcingaWeb2\Link;
 
 abstract class ObjectController extends ActionController
 {
@@ -78,7 +80,11 @@ abstract class ObjectController extends ActionController
                     'add'
                 );
             } else {
-                $this->tabs(new ObjectTabs($this->getType(), $this->getAuth(), $this->object));
+                $this->tabs(new ObjectTabs(
+                    $this->getRequest()->getControllerName(),
+                    $this->getAuth(),
+                    $this->object
+                ));
             }
         }
     }
@@ -145,6 +151,7 @@ abstract class ObjectController extends ActionController
         if ($this->object->isExternal()) {
             $this->addActionClone();
         }
+        $this->addActionBasket();
         $preview->renderTo($this);
     }
 
@@ -233,10 +240,10 @@ abstract class ObjectController extends ActionController
         $this->addTitle($this->translate('Activity Log: %s'), $name);
 
         $db = $this->db();
-        $type = $this->getType();
+        $objectTable = $this->object->getTableName();
         $table = (new ActivityLogTable($db))
             ->setLastDeployedId($db->getLastDeploymentActivityLogId())
-            ->filterObject('icinga_' . $type, $name);
+            ->filterObject($objectTable, $name);
         if ($host = $this->params->get('host')) {
             $table->filterHost($host);
         }
@@ -323,7 +330,15 @@ abstract class ObjectController extends ActionController
         if ($this->hasBasketSupport()) {
             $object = $this->object;
             if ($object instanceof ExportInterface) {
-                if ($object instanceof IcingaServiceSet) {
+                if ($object instanceof IcingaCommand) {
+                    if ($object->isExternal()) {
+                        $type = 'ExternalCommand';
+                    } elseif ($object->isTemplate()) {
+                        $type = 'CommandTemplate';
+                    } else {
+                        $type = 'Command';
+                    }
+                } elseif ($object instanceof IcingaServiceSet) {
                     $type = 'ServiceSet';
                 } elseif ($object->isTemplate()) {
                     $type = ucfirst($this->getType()) . 'Template';
@@ -488,10 +503,22 @@ abstract class ObjectController extends ActionController
 
     protected function addBackToObjectLink()
     {
+        $params = [
+            'name' => $this->object->getObjectName(),
+        ];
+
+        if ($this->object instanceof IcingaService) {
+            if (($host = $this->object->get('host')) !== null) {
+                $params['host'] = $host;
+            } elseif (($set = $this->object->get('service_set')) !== null) {
+                $params['set'] = $set;
+            }
+        }
+
         $this->actions()->add(Link::create(
             $this->translate('back'),
             'director/' . strtolower($this->getType()),
-            ['name'  => $this->object->getObjectName()],
+            $params,
             ['class' => 'icon-left-big']
         ));
 
