@@ -8,6 +8,7 @@ use Icinga\Module\Director\Db;
 use Icinga\Module\Director\Data\Db\DbObject;
 use Icinga\Module\Director\Data\Db\DbObjectWithSettings;
 use Icinga\Module\Director\Exception\NestingError;
+use Icinga\Module\Director\Hook\IcingaObjectFormHook;
 use Icinga\Module\Director\IcingaConfig\StateFilterSet;
 use Icinga\Module\Director\IcingaConfig\TypeFilterSet;
 use Icinga\Module\Director\Objects\IcingaTemplateChoice;
@@ -422,6 +423,16 @@ abstract class DirectorObjectForm extends DirectorForm
                 $el = $this->getElement($k);
                 if ($el) {
                     $this->setInheritedValue($el, $inherited->$k, $origins->$k);
+                } elseif (substr($k, -3) === '_id') {
+                    $k = substr($k, 0, -3);
+                    $el = $this->getElement($k);
+                    if ($el) {
+                        $this->setInheritedValue(
+                            $el,
+                            $object->getRelatedObjectName($k, $v),
+                            $origins->{"${k}_id"}
+                        );
+                    }
                 }
             }
         }
@@ -687,6 +698,24 @@ abstract class DirectorObjectForm extends DirectorForm
         return $this->object !== null;
     }
 
+    public function isIcingaObject()
+    {
+        if ($this->object !== null) {
+            return $this->object instanceof IcingaObject;
+        }
+
+        /** @var DbObject $class */
+        $class = $this->getObjectClassname();
+        $instance = $class::create();
+
+        return $instance instanceof IcingaObject;
+    }
+
+    public function isMultiObjectForm()
+    {
+        return false;
+    }
+
     public function setObject(DbObject $object)
     {
         $this->object = $object;
@@ -772,14 +801,18 @@ abstract class DirectorObjectForm extends DirectorForm
             $this->setDefaultsFromObject($this->object);
         }
         $this->prepareFields($this->object());
+        IcingaObjectFormHook::callOnSetup($this);
         if ($this->hasBeenSent()) {
             $this->handlePost();
         }
         try {
             $this->loadInheritedProperties();
             $this->addFields();
+            $this->callOnRequestCallables();
         } catch (Exception $e) {
             $this->addUniqueException($e);
+
+            return;
         }
 
         if ($this->shouldBeDeleted()) {
@@ -918,7 +951,7 @@ abstract class DirectorObjectForm extends DirectorForm
         return $this->getSentValue($name) === $this->getElement($name)->getLabel();
     }
 
-    protected function abortDeletion()
+    public function abortDeletion()
     {
         if ($this->hasDeleteButton()) {
             $this->setSentValue($this->deleteButtonName, 'ABORTED');
@@ -990,7 +1023,11 @@ abstract class DirectorObjectForm extends DirectorForm
     {
         /** @var DbObject $class */
         $class = $this->getObjectClassname();
-        $this->object = $class::load($id, $this->db);
+        if (is_int($id)) {
+            $this->object = $class::loadWithAutoIncId($id, $this->db);
+        } else {
+            $this->object = $class::load($id, $this->db);
+        }
 
         // TODO: hmmmm...
         if (! is_array($id) && $this->object->getKeyName() === 'id') {
@@ -1150,7 +1187,7 @@ abstract class DirectorObjectForm extends DirectorForm
             return $this;
         }
 
-        if (in_array($this->getObjectShortClassName(), ['TimePeriod'])) {
+        if (in_array($this->getObjectShortClassName(), ['TimePeriod', 'ScheduledDowntime'])) {
             $required = false;
         } else {
             $required = $required !== null ? $required : !$this->isTemplate();
