@@ -4,21 +4,22 @@ namespace Icinga\Module\Director\Web\Tabs;
 
 use Icinga\Authentication\Auth;
 use Icinga\Module\Director\Objects\IcingaObject;
-use dipl\Translation\TranslationHelper;
-use dipl\Web\Widget\Tabs;
+use gipfl\Translation\TranslationHelper;
+use gipfl\IcingaWeb2\Widget\Tabs;
 
 class ObjectsTabs extends Tabs
 {
     use TranslationHelper;
 
-    public function __construct($type, Auth $auth)
+    public function __construct($type, Auth $auth, $typeUrl)
     {
         $object = IcingaObject::createByType($type);
         if ($object->isGroup()) {
-            $object = IcingaObject::createByType(substr($type, 0, -5));
+            $object = IcingaObject::createByType(substr($typeUrl, 0, -5));
         }
+        $shortName = $object->getShortTableName();
 
-        $plType = strtolower(preg_replace('/cys$/', 'cies', $type . 's'));
+        $plType = strtolower(preg_replace('/cys$/', 'cies', $shortName . 's'));
         if ($auth->hasPermission("director/${plType}")) {
             $this->add('index', array(
                 'url'   => sprintf('director/%s', $plType),
@@ -56,7 +57,7 @@ class ObjectsTabs extends Tabs
 
             if ($object->supportsGroups()) {
                 $this->add('groups', array(
-                    'url' => sprintf('director/%sgroups', $type),
+                    'url' => sprintf('director/%sgroups', $typeUrl),
                     'label' => $this->translate('Groups')
                 ));
             }
@@ -65,12 +66,12 @@ class ObjectsTabs extends Tabs
         if ($auth->hasPermission('director/admin')) {
             if ($object->supportsChoices()) {
                 $this->add('choices', array(
-                    'url' => sprintf('director/templatechoices/%s', $type),
+                    'url' => sprintf('director/templatechoices/%s', $shortName),
                     'label' => $this->translate('Choices')
                 ));
             }
         }
-        if ($object->supportsSets() && $auth->hasPermission("director/${type}_sets")) {
+        if ($object->supportsSets() && $auth->hasPermission("director/${typeUrl}sets")) {
             $this->add('sets', array(
                 'url'    => sprintf('director/%s/sets', $plType),
                 'label' => $this->translate('Sets')
