@@ -7,7 +7,28 @@
 -- the frontend or provides everything you need for automated migration
 -- handling. Please find more related information in our documentation.
 
-SET sql_mode = 'STRICT_ALL_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,NO_ENGINE_SUBSTITUTION,PIPES_AS_CONCAT,ANSI_QUOTES,ERROR_FOR_DIVISION_BY_ZERO,NO_AUTO_CREATE_USER';
+SET sql_mode = 'STRICT_ALL_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,NO_ENGINE_SUBSTITUTION,PIPES_AS_CONCAT,ANSI_QUOTES,ERROR_FOR_DIVISION_BY_ZERO';
+
+CREATE TABLE director_daemon_info (
+  instance_uuid_hex VARCHAR(32) NOT NULL, -- random by daemon
+  schema_version SMALLINT UNSIGNED NOT NULL,
+  fqdn VARCHAR(255) NOT NULL,
+  username VARCHAR(64) NOT NULL,
+  pid INT UNSIGNED NOT NULL,
+  binary_path VARCHAR(128) NOT NULL,
+  binary_realpath VARCHAR(128) NOT NULL,
+  php_binary_path VARCHAR(128) NOT NULL,
+  php_binary_realpath VARCHAR(128) NOT NULL,
+  php_version VARCHAR(64) NOT NULL,
+  php_integer_size SMALLINT NOT NULL,
+  running_with_systemd ENUM('y', 'n') NOT NULL,
+  ts_started BIGINT(20) NOT NULL,
+  ts_stopped BIGINT(20) DEFAULT NULL,
+  ts_last_modification BIGINT(20) DEFAULT NULL,
+  ts_last_update BIGINT(20) DEFAULT NULL,
+  process_info MEDIUMTEXT NOT NULL,
+  PRIMARY KEY (instance_uuid_hex)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE utf8mb4_bin;
 
 CREATE TABLE director_activity_log (
   id BIGINT(20) UNSIGNED AUTO_INCREMENT NOT NULL,
@@ -17,7 +38,7 @@ CREATE TABLE director_activity_log (
   old_properties TEXT DEFAULT NULL COMMENT 'Property hash, JSON',
   new_properties TEXT DEFAULT NULL COMMENT 'Property hash, JSON',
   author VARCHAR(64) NOT NULL,
-  change_time DATETIME NOT NULL,
+  change_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   checksum VARBINARY(20) NOT NULL,
   parent_checksum VARBINARY(20) DEFAULT NULL,
   PRIMARY KEY (id),
@@ -28,6 +49,45 @@ CREATE TABLE director_activity_log (
   INDEX checksum (checksum)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
+CREATE TABLE director_basket (
+  uuid VARBINARY(16) NOT NULL,
+  basket_name VARCHAR(64) NOT NULL,
+  owner_type ENUM(
+    'user',
+    'usergroup',
+    'role'
+  ) NOT NULL,
+  owner_value VARCHAR(255) NOT NULL,
+  objects MEDIUMTEXT NOT NULL, -- json-encoded
+  PRIMARY KEY (uuid),
+  UNIQUE INDEX basket_name (basket_name)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE utf8mb4_bin;
+
+CREATE TABLE director_basket_content (
+  checksum VARBINARY(20) NOT NULL,
+  summary VARCHAR(500) NOT NULL, -- json
+  content MEDIUMTEXT NOT NULL, -- json
+  PRIMARY KEY (checksum)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE utf8mb4_bin;
+
+CREATE TABLE director_basket_snapshot (
+  basket_uuid VARBINARY(16) NOT NULL,
+  ts_create BIGINT(20) NOT NULL,
+  content_checksum VARBINARY(20) NOT NULL,
+  PRIMARY KEY (basket_uuid, ts_create),
+  INDEX sort_idx (ts_create),
+  CONSTRAINT basked_snapshot_basket
+  FOREIGN KEY director_basket_snapshot (basket_uuid)
+  REFERENCES director_basket (uuid)
+    ON DELETE CASCADE
+    ON UPDATE RESTRICT,
+  CONSTRAINT basked_snapshot_content
+  FOREIGN KEY content_checksum (content_checksum)
+  REFERENCES director_basket_content (checksum)
+    ON DELETE RESTRICT
+    ON UPDATE RESTRICT
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE utf8mb4_bin;
+
 CREATE TABLE director_generated_config (
   checksum VARBINARY(20) NOT NULL COMMENT 'SHA1(last_activity_checksum;file_path=checksum;file_path=checksum;...)',
   director_version VARCHAR(64) DEFAULT NULL,
@@ -45,7 +105,7 @@ CREATE TABLE director_generated_config (
 
 CREATE TABLE director_generated_file (
   checksum VARBINARY(20) NOT NULL COMMENT 'SHA1(content)',
-  content MEDIUMTEXT NOT NULL,
+  content LONGTEXT NOT NULL,
   cnt_object INT(10) UNSIGNED NOT NULL DEFAULT 0,
   cnt_template INT(10) UNSIGNED NOT NULL DEFAULT 0,
   cnt_apply INT(10) UNSIGNED NOT NULL DEFAULT 0,
@@ -75,9 +135,9 @@ CREATE TABLE director_deployment_log (
   config_checksum VARBINARY(20) DEFAULT NULL,
   last_activity_checksum VARBINARY(20) NOT NULL,
   peer_identity VARCHAR(64) NOT NULL,
-  start_time DATETIME NOT NULL,
-  end_time DATETIME DEFAULT NULL,
-  abort_time DATETIME DEFAULT NULL,
+  start_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
+  end_time TIMESTAMP NULL DEFAULT NULL,
+  abort_time TIMESTAMP NULL DEFAULT NULL,
   duration_connection INT(10) UNSIGNED DEFAULT NULL
     COMMENT 'The time it took to connect to an Icinga node (ms)',
   duration_dump INT(10) UNSIGNED DEFAULT NULL
@@ -145,7 +205,7 @@ CREATE TABLE director_datafield_setting (
 
 CREATE TABLE director_schema_migration (
   schema_version SMALLINT UNSIGNED NOT NULL,
-  migration_time DATETIME NOT NULL,
+  migration_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   PRIMARY KEY(schema_version)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
@@ -197,6 +257,7 @@ CREATE TABLE icinga_timeperiod (
   zone_id INT(10) UNSIGNED DEFAULT NULL,
   object_type ENUM('object', 'template') NOT NULL,
   disabled ENUM('y', 'n') NOT NULL DEFAULT 'n',
+  prefer_includes ENUM('y', 'n') DEFAULT NULL,
   PRIMARY KEY (id),
   UNIQUE INDEX object_name (object_name, zone_id),
   CONSTRAINT icinga_timeperiod_zone
@@ -248,8 +309,8 @@ CREATE TABLE director_job (
   run_interval INT(10) UNSIGNED NOT NULL, -- seconds
   timeperiod_id INT(10) UNSIGNED DEFAULT NULL,
   last_attempt_succeeded ENUM('y', 'n') DEFAULT NULL,
-  ts_last_attempt DATETIME DEFAULT NULL,
-  ts_last_error DATETIME DEFAULT NULL,
+  ts_last_attempt TIMESTAMP NULL DEFAULT NULL,
+  ts_last_error TIMESTAMP NULL DEFAULT NULL,
   last_error_message TEXT DEFAULT NULL,
   PRIMARY KEY (id),
   UNIQUE KEY (job_name),
@@ -280,12 +341,13 @@ CREATE TABLE icinga_command (
   disabled ENUM('y', 'n') NOT NULL DEFAULT 'n',
   methods_execute VARCHAR(64) DEFAULT NULL,
   command TEXT DEFAULT NULL,
+  is_string ENUM('y', 'n') NULL,
   -- env text DEFAULT NULL,
   -- vars text DEFAULT NULL,
   timeout SMALLINT UNSIGNED DEFAULT NULL,
   zone_id INT(10) UNSIGNED DEFAULT NULL,
   PRIMARY KEY (id),
-  UNIQUE INDEX object_name (object_name, zone_id),
+  UNIQUE INDEX object_name (object_name),
   CONSTRAINT icinga_command_zone
     FOREIGN KEY zone (zone_id)
     REFERENCES icinga_zone (id)
@@ -440,7 +502,7 @@ CREATE TABLE icinga_host (
   object_type ENUM('object', 'template') NOT NULL,
   disabled ENUM('y', 'n') NOT NULL DEFAULT 'n',
   display_name VARCHAR(255) DEFAULT NULL,
-  address VARCHAR(64) DEFAULT NULL,
+  address VARCHAR(255) DEFAULT NULL,
   address6 VARCHAR(45) DEFAULT NULL,
   check_command_id INT(10) UNSIGNED DEFAULT NULL,
   max_check_attempts MEDIUMINT UNSIGNED DEFAULT NULL,
@@ -875,6 +937,22 @@ CREATE TABLE icinga_servicegroup_service (
     ON UPDATE CASCADE
 ) ENGINE=InnoDB;
 
+CREATE TABLE icinga_servicegroup_service_resolved (
+  servicegroup_id INT(10) UNSIGNED NOT NULL,
+  service_id INT(10) UNSIGNED NOT NULL,
+  PRIMARY KEY (servicegroup_id, service_id),
+  CONSTRAINT icinga_servicegroup_service_resolved_service
+  FOREIGN KEY service (service_id)
+  REFERENCES icinga_service (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE,
+  CONSTRAINT icinga_servicegroup_service_resolved_servicegroup
+  FOREIGN KEY servicegroup (servicegroup_id)
+  REFERENCES icinga_servicegroup (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
 CREATE TABLE icinga_hostgroup_host (
   hostgroup_id INT(10) UNSIGNED NOT NULL,
   host_id INT(10) UNSIGNED NOT NULL,
@@ -940,6 +1018,11 @@ CREATE TABLE icinga_user (
     FOREIGN KEY zone (zone_id)
     REFERENCES icinga_zone (id)
     ON DELETE RESTRICT
+    ON UPDATE CASCADE,
+  CONSTRAINT icinga_user_period
+    FOREIGN KEY period (period_id)
+    REFERENCES icinga_timeperiod (id)
+    ON DELETE RESTRICT
     ON UPDATE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
@@ -1287,9 +1370,10 @@ CREATE TABLE import_source (
     'failing'
   ) NOT NULL DEFAULT 'unknown',
   last_error_message TEXT DEFAULT NULL,
-  last_attempt DATETIME DEFAULT NULL,
+  last_attempt TIMESTAMP NULL DEFAULT NULL,
   description TEXT DEFAULT NULL,
   PRIMARY KEY (id),
+  UNIQUE INDEX source_name (source_name),
   INDEX search_idx (key_column)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
@@ -1343,8 +1427,8 @@ CREATE TABLE import_run (
   id INT(10) UNSIGNED AUTO_INCREMENT NOT NULL,
   source_id INT(10) UNSIGNED NOT NULL,
   rowset_checksum VARBINARY(20) DEFAULT NULL,
-  start_time DATETIME NOT NULL,
-  end_time DATETIME DEFAULT NULL,
+  start_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
+  end_time TIMESTAMP NULL DEFAULT NULL,
   succeeded ENUM('y', 'n') DEFAULT NULL,
   PRIMARY KEY (id),
   CONSTRAINT import_run_source
@@ -1421,7 +1505,10 @@ CREATE TABLE sync_rule (
     'endpoint',
     'zone',
     'timePeriod',
-    'serviceSet'
+    'serviceSet',
+    'scheduledDowntime',
+    'notification',
+    'dependency'
   ) NOT NULL,
   update_policy ENUM('merge', 'override', 'ignore') NOT NULL,
   purge_existing ENUM('y', 'n') NOT NULL DEFAULT 'n',
@@ -1433,9 +1520,10 @@ CREATE TABLE sync_rule (
     'failing'
   ) NOT NULL DEFAULT 'unknown',
   last_error_message TEXT DEFAULT NULL,
-  last_attempt DATETIME DEFAULT NULL,
+  last_attempt TIMESTAMP NULL DEFAULT NULL,
   description TEXT DEFAULT NULL,
-  PRIMARY KEY (id)
+  PRIMARY KEY (id),
+  UNIQUE INDEX rule_name (rule_name)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 CREATE TABLE sync_property (
@@ -1464,7 +1552,7 @@ CREATE TABLE sync_run (
   id BIGINT(10) UNSIGNED AUTO_INCREMENT NOT NULL,
   rule_id INT(10) UNSIGNED DEFAULT NULL,
   rule_name VARCHAR(255) NOT NULL,
-  start_time DATETIME NOT NULL,
+  start_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   duration_ms INT(10) UNSIGNED DEFAULT NULL,
   objects_deleted INT(10) UNSIGNED DEFAULT 0,
   objects_created INT(10) UNSIGNED DEFAULT 0,
@@ -1609,6 +1697,7 @@ CREATE TABLE icinga_dependency (
   disabled ENUM('y', 'n') NOT NULL DEFAULT 'n',
   apply_to ENUM('host', 'service') DEFAULT NULL,
   parent_host_id INT(10) UNSIGNED DEFAULT NULL,
+  parent_host_var VARCHAR(128) DEFAULT NULL,
   parent_service_id INT(10) UNSIGNED DEFAULT NULL,
   child_host_id INT(10) UNSIGNED DEFAULT NULL,
   child_service_id INT(10) UNSIGNED DEFAULT NULL,
@@ -1690,6 +1779,94 @@ CREATE TABLE icinga_dependency_states_set (
     ON UPDATE CASCADE
 ) ENGINE=InnoDB;
 
+CREATE TABLE icinga_timeperiod_include (
+  timeperiod_id INT(10) UNSIGNED NOT NULL,
+  include_id INT(10) UNSIGNED NOT NULL,
+  PRIMARY KEY (timeperiod_id, include_id),
+  CONSTRAINT icinga_timeperiod_include
+  FOREIGN KEY timeperiod (include_id)
+  REFERENCES icinga_timeperiod (id)
+    ON DELETE RESTRICT
+    ON UPDATE RESTRICT,
+  CONSTRAINT icinga_timeperiod_include_timeperiod
+  FOREIGN KEY include (timeperiod_id)
+  REFERENCES icinga_timeperiod (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE
+);
+
+CREATE TABLE icinga_timeperiod_exclude (
+  timeperiod_id INT(10) UNSIGNED NOT NULL,
+  exclude_id INT(10) UNSIGNED NOT NULL,
+  PRIMARY KEY (timeperiod_id, exclude_id),
+  CONSTRAINT icinga_timeperiod_exclude
+  FOREIGN KEY timeperiod (exclude_id)
+  REFERENCES icinga_timeperiod (id)
+    ON DELETE RESTRICT
+    ON UPDATE RESTRICT,
+  CONSTRAINT icinga_timeperiod_exclude_timeperiod
+  FOREIGN KEY exclude (timeperiod_id)
+  REFERENCES icinga_timeperiod (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE
+);
+
+CREATE TABLE icinga_scheduled_downtime (
+  id INT(10) UNSIGNED AUTO_INCREMENT NOT NULL,
+  object_name VARCHAR(255) NOT NULL,
+  zone_id INT(10) UNSIGNED DEFAULT NULL,
+  object_type ENUM('object', 'template', 'apply') NOT NULL,
+  disabled ENUM('y', 'n') NOT NULL DEFAULT 'n',
+  apply_to ENUM('host', 'service') DEFAULT NULL,
+  assign_filter TEXT DEFAULT NULL,
+  author VARCHAR(255) DEFAULT NULL,
+  comment TEXT DEFAULT NULL,
+  fixed ENUM('y', 'n') DEFAULT NULL,
+  duration INT(10) UNSIGNED DEFAULT NULL,
+  with_services ENUM('y', 'n') NULL DEFAULT NULL,
+  PRIMARY KEY (id),
+  UNIQUE INDEX object_name (object_name),
+  CONSTRAINT icinga_scheduled_downtime_zone
+  FOREIGN KEY zone (zone_id)
+  REFERENCES icinga_zone (id)
+    ON DELETE RESTRICT
+    ON UPDATE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+CREATE TABLE icinga_scheduled_downtime_inheritance (
+  scheduled_downtime_id INT(10) UNSIGNED NOT NULL,
+  parent_scheduled_downtime_id INT(10) UNSIGNED NOT NULL,
+  weight MEDIUMINT UNSIGNED DEFAULT NULL,
+  PRIMARY KEY (scheduled_downtime_id, parent_scheduled_downtime_id),
+  UNIQUE KEY unique_order (scheduled_downtime_id, weight),
+  CONSTRAINT icinga_scheduled_downtime_inheritance_downtime
+  FOREIGN KEY host (scheduled_downtime_id)
+  REFERENCES icinga_scheduled_downtime (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE,
+  CONSTRAINT icinga_scheduled_downtime_inheritance_parent_downtime
+  FOREIGN KEY host (parent_scheduled_downtime_id)
+  REFERENCES icinga_scheduled_downtime (id)
+    ON DELETE RESTRICT
+    ON UPDATE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+CREATE TABLE icinga_scheduled_downtime_range (
+  scheduled_downtime_id INT(10) UNSIGNED AUTO_INCREMENT NOT NULL,
+  range_key VARCHAR(255) NOT NULL COMMENT 'monday, ...',
+  range_value VARCHAR(255) NOT NULL COMMENT '00:00-24:00, ...',
+  range_type ENUM('include', 'exclude') NOT NULL DEFAULT 'include'
+  COMMENT 'include -> ranges {}, exclude ranges_ignore {} - not yet',
+  merge_behaviour ENUM('set', 'add', 'substract') NOT NULL DEFAULT 'set'
+  COMMENT 'set -> = {}, add -> += {}, substract -> -= {}',
+  PRIMARY KEY (scheduled_downtime_id, range_type, range_key),
+  CONSTRAINT icinga_scheduled_downtime_range_downtime
+  FOREIGN KEY scheduled_downtime (scheduled_downtime_id)
+  REFERENCES icinga_scheduled_downtime (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
 INSERT INTO director_schema_migration
   (schema_version, migration_time)
-  VALUES (149, NOW());
+  VALUES (167, NOW());
