@@ -31,7 +31,10 @@ CREATE TYPE enum_sync_rule_object_type AS ENUM(
   'endpoint',
   'zone',
   'timePeriod',
-  'serviceSet'
+  'serviceSet',
+  'scheduledDowntime',
+  'notification',
+  'dependency'
 );
 CREATE TYPE enum_sync_rule_update_policy AS ENUM('merge', 'override', 'ignore');
 CREATE TYPE enum_sync_property_merge_policy AS ENUM('override', 'merge');
@@ -50,6 +53,28 @@ CREATE OR REPLACE FUNCTION unix_timestamp(timestamp with time zone) RETURNS bigi
 ' LANGUAGE sql;
 
 
+CREATE TABLE director_daemon_info (
+  instance_uuid_hex character varying(32) NOT NULL, -- random by daemon
+  schema_version SMALLINT NOT NULL,
+  fqdn character varying(255) NOT NULL,
+  username character varying(64) NOT NULL,
+  pid integer NOT NULL,
+  binary_path character varying(128) NOT NULL,
+  binary_realpath character varying(128) NOT NULL,
+  php_binary_path character varying(128) NOT NULL,
+  php_binary_realpath character varying(128) NOT NULL,
+  php_version character varying(64) NOT NULL,
+  php_integer_size SMALLINT NOT NULL,
+  running_with_systemd enum_boolean DEFAULT NULL,
+  ts_started bigint NOT NULL,
+  ts_stopped bigint DEFAULT NULL,
+  ts_last_modification bigint DEFAULT NULL,
+  ts_last_update bigint NOT NULL,
+  process_info text NOT NULL,
+  PRIMARY KEY (instance_uuid_hex)
+);
+
+
 CREATE TABLE director_activity_log (
   id bigserial,
   object_type character varying(64) NOT NULL,
@@ -415,6 +440,7 @@ CREATE TABLE icinga_command (
   disabled enum_boolean NOT NULL DEFAULT 'n',
   methods_execute character varying(64) DEFAULT NULL,
   command text DEFAULT NULL,
+  is_string enum_boolean NULL,
 -- env text DEFAULT NULL,
   timeout smallint DEFAULT NULL,
   zone_id integer DEFAULT NULL,
@@ -607,7 +633,7 @@ CREATE TABLE icinga_host (
   object_type enum_object_type_all NOT NULL,
   disabled enum_boolean NOT NULL DEFAULT 'n',
   display_name CHARACTER VARYING(255) DEFAULT NULL,
-  address character varying(64) DEFAULT NULL,
+  address character varying(255) DEFAULT NULL,
   address6 character varying(45) DEFAULT NULL,
   check_command_id integer DEFAULT NULL,
   max_check_attempts integer DEFAULT NULL,
@@ -1964,6 +1990,7 @@ CREATE TABLE icinga_dependency (
   disabled enum_boolean DEFAULT 'n',
   apply_to enum_host_service NULL DEFAULT NULL,
   parent_host_id integer DEFAULT NULL,
+  parent_host_var character varying(128) DEFAULT NULL,
   parent_service_id integer DEFAULT NULL,
   child_host_id integer DEFAULT NULL,
   child_service_id integer DEFAULT NULL,
@@ -2084,6 +2111,75 @@ CREATE TABLE icinga_timeperiod_exclude (
   ON UPDATE CASCADE
 );
 
+
+CREATE TABLE icinga_scheduled_downtime (
+  id serial,
+  object_name character varying(255) NOT NULL,
+  zone_id integer DEFAULT NULL,
+  object_type enum_object_type_all NOT NULL,
+  disabled enum_boolean NOT NULL DEFAULT 'n',
+  apply_to enum_host_service NULL DEFAULT NULL,
+  assign_filter text DEFAULT NULL,
+  author character varying(255) DEFAULT NULL,
+  comment text DEFAULT NULL,
+  fixed enum_boolean DEFAULT NULL,
+  duration int DEFAULT NULL,
+  with_services enum_boolean NULL DEFAULT NULL,
+  PRIMARY KEY (id),
+  CONSTRAINT icinga_scheduled_downtime_zone
+  FOREIGN KEY (zone_id)
+  REFERENCES icinga_zone (id)
+    ON DELETE RESTRICT
+    ON UPDATE CASCADE
+);
+
+CREATE UNIQUE INDEX scheduled_downtime_object_name ON icinga_scheduled_downtime (object_name);
+CREATE INDEX scheduled_downtime_zone ON icinga_scheduled_downtime (zone_id);
+
+
+CREATE TABLE icinga_scheduled_downtime_inheritance (
+  scheduled_downtime_id integer NOT NULL,
+  parent_scheduled_downtime_id integer NOT NULL,
+  weight integer DEFAULT NULL,
+  PRIMARY KEY (scheduled_downtime_id, parent_scheduled_downtime_id),
+  CONSTRAINT icinga_scheduled_downtime_inheritance_scheduled_downtime
+  FOREIGN KEY (scheduled_downtime_id)
+  REFERENCES icinga_scheduled_downtime (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE,
+  CONSTRAINT icinga_scheduled_downtime_inheritance_parent_scheduled_downtime
+  FOREIGN KEY (parent_scheduled_downtime_id)
+  REFERENCES icinga_scheduled_downtime (id)
+    ON DELETE RESTRICT
+    ON UPDATE CASCADE
+);
+
+CREATE UNIQUE INDEX scheduled_downtime_inheritance_unique_order ON icinga_scheduled_downtime_inheritance (scheduled_downtime_id, weight);
+CREATE INDEX scheduled_downtime_inheritance_scheduled_downtime ON icinga_scheduled_downtime_inheritance (scheduled_downtime_id);
+CREATE INDEX scheduled_downtime_inheritance_scheduled_downtime_parent ON icinga_scheduled_downtime_inheritance (parent_scheduled_downtime_id);
+
+
+CREATE TABLE icinga_scheduled_downtime_range (
+  scheduled_downtime_id serial,
+  range_key character varying(255) NOT NULL,
+  range_value character varying(255) NOT NULL,
+  range_type enum_timeperiod_range_type NOT NULL DEFAULT 'include',
+  merge_behaviour enum_merge_behaviour NOT NULL DEFAULT 'set',
+  PRIMARY KEY (scheduled_downtime_id, range_type, range_key),
+  CONSTRAINT icinga_scheduled_downtime_range_scheduled_downtime
+  FOREIGN KEY (scheduled_downtime_id)
+  REFERENCES icinga_scheduled_downtime (id)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE
+);
+
+CREATE INDEX scheduled_downtime_range_scheduled_downtime ON icinga_scheduled_downtime_range (scheduled_downtime_id);
+COMMENT ON COLUMN icinga_scheduled_downtime_range.range_key IS 'monday, ...';
+COMMENT ON COLUMN icinga_scheduled_downtime_range.range_value IS '00:00-24:00, ...';
+COMMENT ON COLUMN icinga_scheduled_downtime_range.range_type IS 'include -> ranges {}, exclude ranges_ignore {} - not yet';
+COMMENT ON COLUMN icinga_scheduled_downtime_range.merge_behaviour IS 'set -> = {}, add -> += {}, substract -> -= {}';
+
+
 INSERT INTO director_schema_migration
   (schema_version, migration_time)
-  VALUES (158, NOW());
+  VALUES (167, NOW());
